@@ -1,24 +1,24 @@
 
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_TARNAME "am-utils"
-#define PACKAGE_VERSION "6.1.1-rc1"
-#define PACKAGE_STRING "am-utils 6.1.1-rc1"
+#define PACKAGE_VERSION "6.2a2"
+#define PACKAGE_STRING "am-utils 6.2a2"
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "powerpc"
 #define HOST_VENDOR "ibm"
-#define HOST_OS "aix5.2.0.0"
+#define HOST_OS "aix5.3.0.0"
 #define HOST_OS_NAME "aix5"
-#define HOST_OS_VERSION "5.2.0.0"
+#define HOST_OS_VERSION "5.3.0.0"
 #define HOST_ARCH "00CBE20D4C00"
 #define DISTRO_NAME "none"
-#define HOST_NAME "a-aix52p.fsl.cs.sunysb.edu"
+#define HOST_NAME "a-aix53p"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Fri Jul 15 10:29:33 EDT 2005"
+#define CONFIG_DATE "Thu May 11 10:28:15 EST 2006"
 #define PACKAGE_NAME "am-utils"
-#define PACKAGE_VERSION "6.1.1-rc1"
+#define PACKAGE_VERSION "6.2a2"
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.1.1-rc1"
+#define VERSION "6.2a2"
 #define _ALL_SOURCE 1
 #define DEBUG 1
 #define STDC_HEADERS 1
@@ -32,13 +32,9 @@
 #define HAVE_STDINT_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
-#ifdef __cplusplus
-#include <stdlib.h>
-#endif
-#define HOST_HEADER_VERSION "5.2.0.0"
+#define HOST_HEADER_VERSION "5.3.0.0"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
-#define HAVE_LIBLDAP 1
 #define HAVE_LIBRT 1
 #define HAVE_UNISTD_H 1
 #define HAVE_FORK 1
@@ -87,6 +83,8 @@
 #define HAVE_SIGNAL 1
 #define HAVE_SIGSUSPEND 1
 #define HAVE_SOCKET 1
+#define HAVE_STATFS 1
+#define HAVE_STATVFS 1
 #define HAVE_STRCASECMP 1
 #define HAVE_STRCHR 1
 #define HAVE_STRCSPN 1
@@ -160,6 +158,7 @@
 #define HAVE_SYS_SOCKET_H 1
 #define HAVE_SYS_STAT_H 1
 #define HAVE_SYS_STATFS_H 1
+#define HAVE_SYS_STATVFS_H 1
 #define HAVE_SYS_SYSLOG_H 1
 #define HAVE_SYS_TIME_H 1
 #define HAVE_SYS_TIUSER_H 1
@@ -196,7 +195,9 @@
 #define HAVE_SYSLOG_H 1
 #define HAVE_TIME_H 1
 #define HAVE_TIUSER_H 1
+#define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
+#define NEW_DBM_H "ndbm.h"
 #define TIME_WITH_SYS_TIME 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_aix5_2.h"
 #define HAVE_STRUCT_MNTENT 1
@@ -217,6 +218,7 @@
 #define XDRPROC_T_TYPE xdrproc_t
 #define WORDS_BIGENDIAN 1
 #define voidp void *
+#define HAVE_C99_VARARGS_MACROS 1
 #define HAVE_EXTERN_SYS_ERRLIST 1
 #define HAVE_EXTERN_OPTARG 1
 #define HAVE_EXTERN_CLNT_SPCREATEERROR 1
@@ -230,6 +232,7 @@
 #define HAVE_EXTERN_GETWD 1
 #define HAVE_EXTERN_INNETGR 1
 #define HAVE_EXTERN_MKSTEMP 1
+#define HAVE_EXTERN_MNTCTL 1
 #define HAVE_EXTERN_SBRK 1
 #define HAVE_EXTERN_SETEUID 1
 #define HAVE_EXTERN_SETITIMER 1
@@ -240,7 +243,6 @@
 #define HAVE_EXTERN_UALARM 1
 #define HAVE_EXTERN_USLEEP 1
 #define HAVE_EXTERN_WAIT3 1
-#define HAVE_EXTERN_VSNPRINTF 1
 #define HAVE_EXTERN_XDR_CALLMSG 1
 #define HAVE_EXTERN_XDR_OPAQUE_AUTH 1
 #define HAVE_LONG_FILE_NAMES 1
@@ -248,12 +250,16 @@
 #define HAVE_FD_SET_FDS_BITS 1
 #define HAVE_STRUCT_FHSTATUS_FHS_FH 1
 #define HAVE_NFS_ARGS_T_ACDIRMIN 1
+#define HAVE_NFS_ARGS_T_ACDIRMAX 1
 #define HAVE_NFS_ARGS_T_ACREGMIN 1
+#define HAVE_NFS_ARGS_T_ACREGMAX 1
 #define HAVE_NFS_ARGS_T_PROTO 1
 #define HAVE_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_STRUCT_SOCKADDR_SA_LEN 1
 #define HAVE_MAP_FILE 1
+#define HAVE_MAP_SUN 1
 #define HAVE_MAP_EXEC 1
+#define HAVE_MAP_NDBM 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_PASSWD 1
 #define HAVE_MAP_UNION 1
@@ -302,6 +308,7 @@
 #define MNTTAB_OPT_TIMEO "timeo"
 #define MNTTAB_OPT_VERS "vers"
 #define MNTTAB_OPT_WSIZE "wsize"
+#define MNT2_GEN_OPT_FORCE 0x1
 #define MNT2_GEN_OPT_NODEV 0x80
 #define MNT2_GEN_OPT_NOSUID 0x40
 #define MNT2_NFS_OPT_ACDIRMAX 0x800
